@@ -1,10 +1,8 @@
-version = "1.29"
+version = "1.31"
 
 # tools
 dblatex = ''
 fop = ''
-highlight = '/usr/bin/source-highlight'
-highlight_options = '-t4 -s$SRC_LANG -cstyle.css --no-doc -i'
 pkg_config = '/usr/bin/pkg-config'
 xsltproc = '/usr/bin/xsltproc'
 
